@@ -1,17 +1,18 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd4.4"
+#define HOST_OS "freebsd4.5"
 #define HOST_OS_NAME "freebsd4"
-#define HOST_OS_VERSION "4.4"
+#define HOST_OS_VERSION "4.5"
 #define HOST_ARCH "i386"
-#define HOST_NAME "a-freebsd44.fsl.cs.sunysb.edu"
+#define HOST_NAME "localhost"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Wed Nov 14 17:55:01 EST 2001"
+#define CONFIG_DATE "Tue Feb 26 03:12:24 EST 2002"
+#define PACKAGE_NAME "am-utils"
+#define PACKAGE_VERSION "6.1a6-pre"
+#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.8s1"
-#define PACKAGE "am-utils"
-#define VERSION "6.0.8s1"
+#define VERSION "6.1a6-pre"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -23,7 +24,7 @@
 #define HAVE_INTTYPES_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "4.4"
+#define HOST_HEADER_VERSION "4.5"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
@@ -33,6 +34,8 @@
 #define HAVE_WORKING_VFORK 1
 #define HAVE_WORKING_FORK 1
 #define HAVE_WAIT3 1
+#define GETPGRP_VOID 1
+#define SETPGRP_VOID 1
 #define HAVE__SETERR_REPLY 1
 #define HAVE_BCMP 1
 #define HAVE_BCOPY 1
@@ -158,11 +161,13 @@
 #define HAVE_RPCSVC_NIS_H 1
 #define HAVE_RPCSVC_YP_PROT_H 1
 #define HAVE_RPCSVC_YPCLNT_H 1
+#define HAVE_SYS_DIR_H 1
 #define HAVE_SYS_ERRNO_H 1
 #define HAVE_SYS_FILE_H 1
 #define HAVE_SYS_IOCTL_H 1
 #define HAVE_SYS_LOCK_H 1
 #define HAVE_SYS_MBUF_H 1
+#define HAVE_SYS_MMAN_H 1
 #define HAVE_SYS_MOUNT_H 1
 #define HAVE_SYS_PARAM_H 1
 #define HAVE_SYS_PROC_H 1
@@ -188,6 +193,7 @@
 #define HAVE_IFADDRS_H 1
 #define HAVE_GRP_H 1
 #define HAVE_LIBGEN_H 1
+#define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_NDBM_H 1
 #define HAVE_NETDB_H 1
@@ -239,6 +245,7 @@
 #define HAVE_EXTERN_GETLOGIN 1
 #define HAVE_EXTERN_GETPAGESIZE 1
 #define HAVE_EXTERN_GETWD 1
+#define HAVE_EXTERN_INNETGR 1
 #define HAVE_EXTERN_MKSTEMP 1
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
@@ -250,28 +257,29 @@
 #define HAVE_EXTERN_USLEEP 1
 #define HAVE_EXTERN_WAIT3 1
 #define HAVE_EXTERN_VSNPRINTF 1
+#define HAVE_EXTERN_XDR_CALLMSG 1
 #define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_UNISTD_H 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
-#define HAVE_FIELD_CDFS_ARGS_T_FLAGS 1
-#define HAVE_FIELD_CDFS_ARGS_T_FSPEC 1
-#define HAVE_FIELD_CDFS_ARGS_T_SSECTOR 1
-#define HAVE_FIELD_PCFS_ARGS_T_FSPEC 1
-#define HAVE_FIELD_PCFS_ARGS_T_GID 1
-#define HAVE_FIELD_PCFS_ARGS_T_MASK 1
-#define HAVE_FIELD_PCFS_ARGS_T_UID 1
-#define HAVE_FIELD_UFS_ARGS_T_FSPEC 1
-#define HAVE_FIELD_STRUCT_STATFS_F_FSTYPENAME 1
-#define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
-#define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
-#define HAVE_FIELD_NFS_ARGS_T_FHSIZE 1
-#define HAVE_FIELD_NFS_ARGS_T_PROTO 1
-#define HAVE_FIELD_NFS_ARGS_T_SOTYPE 1
-#define HAVE_FIELD_NFS_ARGS_T_VERSION 1
-#define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
-#define HAVE_FIELD_STRUCT_IFADDRS_IFA_NEXT 1
-#define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
+#define HAVE_CDFS_ARGS_T_FLAGS 1
+#define HAVE_CDFS_ARGS_T_FSPEC 1
+#define HAVE_CDFS_ARGS_T_SSECTOR 1
+#define HAVE_PCFS_ARGS_T_FSPEC 1
+#define HAVE_PCFS_ARGS_T_GID 1
+#define HAVE_PCFS_ARGS_T_MASK 1
+#define HAVE_PCFS_ARGS_T_UID 1
+#define HAVE_UFS_ARGS_T_FSPEC 1
+#define HAVE_STRUCT_STATFS_F_FSTYPENAME 1
+#define HAVE_NFS_ARGS_T_ACDIRMIN 1
+#define HAVE_NFS_ARGS_T_ACREGMIN 1
+#define HAVE_NFS_ARGS_T_FHSIZE 1
+#define HAVE_NFS_ARGS_T_PROTO 1
+#define HAVE_NFS_ARGS_T_SOTYPE 1
+#define HAVE_NFS_ARGS_T_VERSION 1
+#define HAVE_STRUCT_IFREQ_IFR_ADDR 1
+#define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
+#define HAVE_STRUCT_SOCKADDR_SA_LEN 1
 #define HAVE_MAP_FILE 1
 #define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
